GoogleMapsUtilsMath class

Instance wrapper around MathUtils for use via GoogleMapsUtils.math.

Properties

earthRadius → double
Earth's mean radius in meters (IUGG).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

arcHav(double x) → double
Inverse haversine.
clamp(double x, double low, double high) → double
Restricts x to [low, high].
hav(double x) → double
Haversine of x (angle in radians).
havDistance(double lat1, double lat2, double dLng) → double
Haversine distance on the unit sphere.
havFromSin(double x) → double
hav(asin(x)).
inverseMercator(double y) → double
Latitude (in radians) from Mercator Y y.
mercator(double lat) → double
Mercator Y from latitude lat (in radians).
mod(double x, double m) → double
Non-negative remainder of x / m.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sinFromHav(double h) → double
sin(|x|) given hav(x).
sinSumFromHav(double x, double y) → double
sin(arcHav(x) + arcHav(y)).
toString() → String
A string representation of this object.
inherited
wrap(double n, double min, double max) → double
Wraps n into [min, max).

Operators

operator ==(Object other) → bool
The equality operator.
inherited