distanceToLine method
Distance from p to the line segment from start to end, in meters.
Implementation
double distanceToLine(
Point<double> p, Point<double> start, Point<double> end) =>
PolyUtils.distanceToLine(p, start, end);
Distance from p to the line segment from start to end, in meters.
double distanceToLine(
Point<double> p, Point<double> start, Point<double> end) =>
PolyUtils.distanceToLine(p, start, end);