interpolate method
Returns the point at fraction of the way between from and to.
Implementation
Point<double> interpolate(
Point<double> from, Point<double> to, double fraction) =>
SphericalUtils.interpolate(from, to, fraction);
Returns the point at fraction of the way between from and to.
Point<double> interpolate(
Point<double> from, Point<double> to, double fraction) =>
SphericalUtils.interpolate(from, to, fraction);