toBoundsFromPoints method
Computes the smallest bounding box that contains all points.
Implementation
GoogleMapsUtilsLatLngBounds toBoundsFromPoints(List<Point<double>> points) =>
SphericalUtils.toBoundsFromPoints(points);
Computes the smallest bounding box that contains all points.
GoogleMapsUtilsLatLngBounds toBoundsFromPoints(List<Point<double>> points) =>
SphericalUtils.toBoundsFromPoints(points);