isLocationOnEdgeTolerance static method
Computes whether the given point lies on or near the edge of a polygon, within a specified tolerance in meters. The polygon edge is composed of great circle segments if geodesic is true, and of Rhumb segments otherwise. The polygon edge is implicitly closed -- the closing segment between the first point and the last point is included.
Implementation
static bool isLocationOnEdgeTolerance(Point<double> point,
List<Point<double>> polygon, bool geodesic, double tolerance) =>
_isLocationOnEdgeOrPath(point, polygon, true, geodesic, tolerance);