isLocationOnPathTolerance static method
Computes whether the given point lies on or near a polyline, within a
specified tolerance in meters. The polyline is composed of great circle
segments if geodesic is true, and of Rhumb segments otherwise. The
polyline is not closed — the closing segment between the first point and
the last point is not included.
Implementation
static bool isLocationOnPathTolerance(Point<double> point,
List<Point<double>> polyline, bool geodesic, double tolerance) =>
_isLocationOnEdgeOrPath(point, polyline, false, geodesic, tolerance);