computeSignedArea static method
Returns the signed area of a closed path on Earth. The sign of the area
may be used to determine the orientation of the path. "Inside" is the
surface that does not contain the South Pole.
Returns the area in square meters.
Implementation
static double computeSignedArea(List<Point<double>> path) =>
_computeSignedAreaWithRadius(path, MathUtils.earthRadius);