computeSignedAreaTest static method

double computeSignedAreaTest(
  1. List<Point<double>> path,
  2. double radius
)

Returns the signed area of a closed path on a sphere of given radius. The computed area uses the same units as the radius squared.

This is exposed for testing; prefer computeSignedArea for production use.

Implementation

static double computeSignedAreaTest(
        List<Point<double>> path, double radius) =>
    _computeSignedAreaWithRadius(path, radius);