GoogleMapsUtilsSpherical class
Instance wrapper around SphericalUtils for use via GoogleMapsUtils.spherical.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
centerFromLatLngBounds(
GoogleMapsUtilsLatLngBounds bounds) → Point< double> -
Returns the center point of the given
bounds. -
computeAngleBetween(
Point< double> from, Point<double> to) → double -
Returns the angle between
fromandto, in radians. -
computeArea(
List< Point< path) → doubledouble> > -
Returns the area enclosed by
path, in square meters. -
computeDistanceBetween(
Point< double> from, Point<double> to) → double -
Returns the distance between
fromandto, in meters. -
computeHeading(
Point< double> from, Point<double> to) → double -
Returns the heading from
fromtotoin degrees [-180, 180). -
computeLength(
List< Point< path) → doubledouble> > -
Returns the length of the given
path, in meters. -
computeOffset(
Point< double> from, double distance, double heading) → Point<double> -
Returns the point at
distancemeters fromfromalongheading. -
computeOffsetOrigin(
Point< double> to, double distance, double heading) → Point<double> ? -
Returns the origin given a destination
to,distance, andheading. -
computeSignedArea(
List< Point< path) → doubledouble> > -
Returns the signed area of
path(positive = counter-clockwise). -
distanceRadians(
double lat1, double lng1, double lat2, double lng2) → double - Returns distance on the unit sphere (radians in, radians out).
-
getCardinal(
double angle) → String -
Returns a 16-point compass cardinal abbreviation for the given
angle. -
interpolate(
Point< double> from, Point<double> to, double fraction) → Point<double> -
Returns the point at
fractionof the way betweenfromandto. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBounds(
double x, double y, double radiusInMeters) → GoogleMapsUtilsLatLngBounds -
Creates a bounding box centered at (
x,y) withradiusInMeters. -
toBoundsFromPoints(
List< Point< points) → GoogleMapsUtilsLatLngBoundsdouble> > -
Computes the smallest bounding box that contains all
points. -
toDegrees(
double rad) → double -
Converts
radradians to degrees. -
toRadians(
double deg) → double -
Converts
degdegrees to radians. -
toString(
) → String -
A string representation of this object.
inherited
-
toSubBounds(
GoogleMapsUtilsLatLngBounds bounds, {int division = 2}) → List< GoogleMapsUtilsLatLngBounds> -
Splits
boundsinto a grid ofdivision² sub-bounds.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited