GoogleMapsUtilsLatLngBounds class
Axis-aligned latitude/longitude bounding box.
Constructors
-
GoogleMapsUtilsLatLngBounds({required Point<
double> northEast, required Point<double> southWest}) -
Creates a bounding box from
northEastandsouthWestcorners.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
northEast
→ Point<
double> -
The north-east corner of the bounding box.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
southWest
→ Point<
double> -
The south-west corner of the bounding box.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override